/*==============================================================================
File name: 		Chinese_World_Bank_Lending_Terms_Analysis_20200305_FINAL.do
AUTHOR:			Alysha Gardner

Date Created: 	02/28/2020
Date Updated: 	03/05/2020

Description: 	This program creates descriptive statistics on lending terms, 
				volumes, and concessionality for a comparative analysis of Chinese
				and World Bank lending terms. 

Inputs:			"$output/Full Dataset"
				"$input/Data_Extract_From_International_Debt_Statistics (1).xlsx"
				"$output/Inflation deflators USD 2014"

Outputs:		"$output/private sector"

SUMMARY: 		This program creates descriptive statistics on lending terms, 
				volumes, and concessionality for a comparative analysis of Chinese
				and World Bank lending terms. 
				
				- Section 4 Analysis of the Full Sample
					Fig 1 	Volume of financing over time
					Fig 2 	Loan concessionality over time
					Tab 2 	At a Glance: Financing from China and the World Bank
				
				- Section 4.1 Geographical Financing Patterns
					Fig 3. 	Cumulative financing and portfolio concessionality by region
				
				- Section 4.2 Assessing Adherence to Concessionality Principles
					Tab 3	Portfolio Concessionality by Income Level
					Fig 4	Portfolio Concessionality and Weighted Average Lending
							Terms by World Bank Lending Categories

				- Section 4.3 Institutional Approaches to Concessionality
					Fig 5	Breakdown of Chinese Official Financing by Institutions
					Tab 4	Portfoli oConcessionality by Official Chinese Financier
					Fig 6	Frequency of China Eximbank Loans, by Grant Element
				
				- Section 5: Analysis of the Subsample
					Tab 5	Difference-in-means test for full sample and outsample
					Fig 7	Portfolio concessionality by country in the subsample
					Tab 6	Lending Terms of Subset Countries
					
				


================================================================================
PRELIMINARIES
==============================================================================*/

clear
set more off

//set directory
if "`c(username)'" == "agardner" {
	global root "/Users/agardner/OneDrive - Center for Global Development/Personal/China Development Initiative/Chinese and World Bank Lending Terms"
	}

global data 	"$root/data"
global input	"$root/data/input"
global output	"$root/data/output"
global dofile	"$root/do"
global figures	"$root/figures"
cd "$root"

use	"$output/Full Dataset", clear
graph set window fontface "PT Sans"
//ssc install asgen

/*==============================================================================
SECTION 4 ANALYSIS OF THE FULL SAMPLE
==============================================================================*/
use	"$output/Full Dataset", clear
drop if country=="China"

//FIGURE 1 Volume of financing over time
	preserve
	
	//create graph by volume of lending
		collapse (sum) amount, by (source year)
		gen amount2=amount/1000000000
		sort source year
		xtset source year
		
		xtline amount2, overlay plot1opts(lcolor("255 191 63") lwidth (medthick)) ///
								plot2opts(lcolor("0 103 127") lwidth (medthick)) ///
								scheme(s1color) ///
								ylab(0 "$0" 20 "$20" 40 "$40" 60 "$60" 80 "$80", ///
									format(%15.0fc) angle(horizontal)) ///
								yti("Total volume of financing, USD Billion") ///
								xti("Year")
	//save
		graph export "$figures/fig 1 volume of financing.png", as (png) replace

	restore

	
//FIGURE 2 Loan concessionality over time	
	preserve
	
	//create graph by average grant element
		replace grantelement_b=. if grantelement==.
		collapse (mean) grantelement_b if type==2, by (source year)
		sort source year
		xtset source year
			
		xtline grantelement_b, overlay 	plot1opts(lcolor("255 191 63") lwidth (medthick)) ///
										plot2opts(lcolor("0 103 127") lwidth (medthick)) ///
										scheme(s1color) ///
										ylab(0 "0" .25 "25%" .35 "35%".5 "50%", ///
											format(%15.0g) angle(horizontal)) ///
										yti("Average grant element") ///
										yline(.25 .35, lpattern(dash) lcolor("105 97 88")) ///
										xti("Year")
			
	//save
		graph export "$figures/fig 2 loan concessionality over time.png", as(png) replace	

	restore	
		
	
//TABLE 2 At a Glance: Financing from China and the World Bank
	preserve
	
	//Total financing (USD)
		table source, contents (sum amount) format(%15.0fc)
		
	//Average loan/grant size
		table source type, contents (mean amount) format(%15.0fc) 
	
	//Total no. of projects
		tab source	
	
	//Volume of Grants/Loans
		table type source, contents (sum amount) format(%15.0fc)
			//transfer to excel for percentage calculations
						
	//Weighted mean interest rates, maturity, and grace period
		foreach x of var interest maturity grace{
			bysort source: asgen wm_`x' = `x', w(amount)
			}
			
			format wm_interest %9.4fc
			format wm_maturity wm_grace %9.1fc
			
		foreach x of var interest maturity grace {
			tab source if type==2, sum (wm_`x') nof nost
			}

	restore

	
	//TABLE 2 Footnote (look at World Bank statistics including lending to China)
		use	"$output/Full Dataset", clear
		preserve

		//Total financing (USD)
			table source, contents (sum amount) format(%15.0fc)
			
		//Average loan/grant size (USD)
			table source type, contents (mean amount) format(%15.0fc) 
		
		//Total no. of projects
			tab source
				
		//Volumen of Grants/Loans
			table type source, contents (sum amount) format(%15.0fc)
				//transfer to excel for calculations
							
		// Weighted Mean interest rates, maturity, and grace period
			foreach x of var interest maturity grace{
				bysort source: asgen wm_`x' = `x', w(amount)
				}
				
				format wm_interest %9.4fc
				format wm_maturity wm_grace %9.1fc
				
			foreach x of var interest maturity grace {
				tab source if type==2, sum (wm_`x') nof nost
				}

		restore


/*==============================================================================
SECTION 4.1 GEOGRAPHICAL FINANCING PATTERNS
==============================================================================*/
use	"$output/Full Dataset", clear
drop if country=="China"

//FIGURE 3 Cumulative financing and portfolio concessionality by region
	//cumulative financing
		table region source, contents (sum amount) format(%15.0fc)
	
	//portfolio concessionality 
		preserve

		//Percent Grant Funding
			//generate total lending stats
				bysort region source: egen ttlending_loan=total(amount) if type==2
					gsort region source -type
					replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=.
						
			//total grant stats				
				bysort region source: egen ttlending_grant=total(amount) if type==1
					gsort region source type
					replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=.
							
			//weighted percent of grants
				gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
		
		//Weighted Means (interest rate, maturity, grace period)
			//create weighted averages for interest, maturity, and grace period
				foreach x of varlist interest maturity grace {
					bysort source region: asgen wm_`x' = `x', w(amount)
					}
						
		//Loan concessionality (derived from weighted means)
			gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
								(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
				la var loan_concess "Grant element by region, unbounded"
				
			gen loan_concess2 = 100*loan_concess
				la var loan_concess2 "Grant element by region, bounded 0-100"	
				format loan_concess2 %9.2fc
				replace loan_concess2 = 0 if loan_concess<=0
				replace loan_concess2 = 100 if loan_concess>=1
		
		//Portfolio concessionality

			//generate Nested Grant dollar amount
				gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
					gsort region source -type
					replace nested_grant=nested_grant[_n-1] if nested_grant>=.
			
			//generate Portfolio Concessionality
				gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
					replace concess = 0 if concess<=0
					replace concess = 100 if concess>=100
					format concess %9.2fc
			
			//get stats
					tab region source, sum(concess) nof nost

		restore
			

		
/*==============================================================================
SECTION 4.2 ASSESSING ADHERENCE TO CONCESSIONALITY PRINCIPLES
==============================================================================*/
use	"$output/Full Dataset", clear
drop if country=="China"

//TABLE 3 portfolio concessionality by income level
	preserve

	//Percent Grant Funding
		//generate total lending stats
			bysort income source: egen ttlending_loan=total(amount) if type==2
				gsort income source -type
				replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=.
					
		//total grant stats				
			bysort income source: egen ttlending_grant=total(amount) if type==1
				gsort income source type
				replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=.
						
		//weighted percent of grants
			gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
	
	//Weighted Means (interest rate, maturity, grace period)
		//create weighted averages for interest, maturity, and grace period
			foreach x of varlist interest maturity grace {
				bysort source income: asgen wm_`x' = `x', w(amount)
				}
		
	//Loan concessionality (derived from weighted means)
		gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
							(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
			la var loan_concess "Grant element by income, unbounded"
				
		gen loan_concess2 = 100*loan_concess
			la var loan_concess2 "Grant element by income, bounded 0-100"
			format loan_concess2 %9.2fc
			replace loan_concess2 = 0 if loan_concess<=0
			replace loan_concess2 = 100 if loan_concess>=1	
	
	//Portfolio concessionality
	
		//generate Nested Grant dollar amount
			gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
				gsort income source -type
				replace nested_grant=nested_grant[_n-1] if nested_grant>=.
			
		//create variable of portfolio concessionality
			gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
				replace concess = 0 if concess<=0
				replace concess = 100 if concess>=100
				format concess %9.2fc
			
		//get stats
			tab income source, sum(concess) nof nost

	restore



//FIGURE 4 Portfolio Concessionality and Weighted Average Lending Terms by World Bank Lending Categories
preserve

	//Adjustments to World Bank lending group status
		replace lendgrp=1	if country==	"Kosovo"					//NB to IDA
		replace lendgrp=1 	if country==	"Vanuatu"					//NB to IDA
		replace lendgrp=1	if country==	"Montenegro"& year<=2005	//NB to IDA
		replace lendgrp=3   if country==	"Nauru"						//NB to IBRD

	//Percent Grant Funding
		//generate total lending stats
			bysort lendgrp source: egen ttlending_loan=total(amount) if type==2
				gsort lendgrp source -type
				replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=.
					
		//total grant stats				
			bysort lendgrp source: egen ttlending_grant=total(amount) if type==1
				gsort lendgrp source type
				replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=.
						
		//weighted percent of grants
			gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
	
	//Weighted Means (interest rate, maturity, grace period)
		//create weighted averages for interest, maturity, grace period
			foreach x of varlist interest maturity grace {
				bysort source lendgrp: asgen wm_`x' = `x', w(amount)
				}
	
	//Loan concessionality (derived from weighted means)
		gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
							(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
			la var loan_concess "Grant element by lending group, unbounded"
			
		gen loan_concess2 = 100*loan_concess
			la var loan_concess2 "Grant element by lending group, bounded 0-100"
			format loan_concess2 %9.2fc
			replace loan_concess2 = 0 if loan_concess<=0
			replace loan_concess2 = 100 if loan_concess>=1
		
	//Portfolio concessionality
		//generate Nested Grant dollar amount
			gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
				gsort lendgrp source -type
				replace nested_grant=nested_grant[_n-1] if nested_grant>=.
			
		//create variable of portfolio concessionality
			gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
				replace concess = 0 if concess<=0
				replace concess = 100 if concess>=100
				format concess %9.2fc
		
		//get stats
			tab lendgrp source, sum(concess) nof nost
				
	restore	
	
	
	
/*==============================================================================
SECTION 4.3 INSTITUTIONAL APPROACHES TO CONCESSIONALITY
==============================================================================*/
use	"$output/Full Dataset", clear
drop if country=="China"

//FIGURE 5 Breakdown of Chinese Official Financing by Institution
	preserve
	
	drop if source==1		//World Bank
	
	tab lender [aw=amount]
	tab lender_d [aw=amount]
	
	//use excel to format table
	
	restore

//TABLE 4 Portfolio Concessionality by Official Chinese Financier
	//State-owned Commerical Bank Stats
		preserve

		drop if country=="China"
		drop if source==1			//World Bank
		keep if lender==4

		
		//Percent Grant Funding
			//gen total lending stats
				bysort lender: egen ttlending_loan=total(amount) if type==2
					gsort lender -type
					replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=. & lender==lender[_n-1]
					
			//total grant stats				
				bysort lender: egen ttlending_grant=total(amount) if type==1
					gsort lender type
					replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=. & lender==lender[_n-1]
					replace ttlending_grant=0 if lender==3 | lender==4	//SOE or SOB (no grants, only loans)
						
			//get weighted percent of grants
				gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
	
		//Weighted Means (interest rate, maturity, grace period)
			//create weighted averages for interest, maturity, and grace period
				foreach x of varlist interest maturity grace {
					bysort lender: asgen wm_`x' = `x', w(amount)
					}
			
	
		//Loan concessionality (derived from weighted means)
			gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
								(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
				la var loan_concess "Grant element by lender type, unbounded"
			
			gen loan_concess2 = 100*loan_concess
				la var loan_concess2 "Grant element by lender type, bounded 0-100"
				format loan_concess2 %9.2fc
				replace loan_concess2 = 0 if loan_concess<=0
				replace loan_concess2 = 100 if loan_concess>=1
			
		//Portfolio concessionality
			//generate Nested Grant dollar amount
				gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
					gsort lender -type
					replace nested_grant=nested_grant[_n-1] if nested_grant>=.
				
			//create variable of portfolio concessionality
				gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
					replace concess = 0 if concess<=0
					replace concess = 100 if concess>=100
					format concess %9.2fc
				
			//get stats
				tab lender, sum(concess) nof nost

		restore
	
	//China Development Bank and China Export-Import Bank Stats
		preserve

		drop if source==1					//World Bank
		keep if lender_d==4|lender_d==5		//CDB and China EximBank
	
		//Percent Grant Funding
			//generate total lending stats
				bysort lender_d: egen ttlending_loan=total(amount) if type==2
					gsort lender_d -type
					replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=. & lender_d==lender_d[_n-1]
					
			//total grant stats				
				bysort lender_d: egen ttlending_grant=total(amount) if type==1
					gsort lender_d type
					replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=. & lender_d==lender_d[_n-1]

			//weighted percent of grants
				gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
	
		//Weighted Means (interest rate, maturity, grace period)
			//create weighted averages for interest, maturity, and grace period
				foreach x of varlist interest maturity grace {
					bysort lender_d: asgen wm_`x' = `x', w(amount)
					}
		
	
		//Loan concessionality (derived from weighted means)
			gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
								(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
			la var loan_concess "Grant element by lender, unbounded"
			
			gen loan_concess2 = 100*loan_concess
				la var loan_concess2 "Grant element by lender, bounded 0-100"
				format loan_concess2 %9.2fc
				replace loan_concess2 = 0 if loan_concess<=0
				replace loan_concess2 = 100 if loan_concess>=1
		
			table lender_d if type==2, c(mean loan_concess2) 
	
		//Portfolio concessionality
			//generate nested grant dollar amount within loans by country
				gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
				gsort lender_d -type
				replace nested_grant=nested_grant[_n-1] if nested_grant>=.
			
			//create variable of portfolio concessionality
				gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
				replace concess = 0 if concess<=0
				replace concess = 100 if concess>=100
				format concess %9.2fc
	
			//get stats
				tab lender_d, sum(concess) nof nost

		restore	


//(NOT A TABLE) CDB/China Exim lending stats for LICs
	preserve
		//create weighted averages for interest, maturity, and grace period
			foreach x of varlist interest maturity grace {
					bysort lender_d: asgen wm`x'LIC = `x' if income==3, w(amount)
					}
					
		//find weighted average statistics by type
			foreach y of varlist wminterestLIC wmmaturityLIC wmgraceLIC {
				tab lender_d if type==2, sum (`y') nof 
				}
	restore
				

				
				
//FIGURE 6: CHINA EXIM BANK LOAN FREQUENCY 

	preserve
	keep if lender_d==5 	//China Exim Bank observations
		
	//histogram
		graph twoway 	(histogram grantelement_b, ///
						freq fcolor("0 103 127") ///
						lcolor(white) ///
						bin(13) ///
						xtitle("Grant Element") ///
						xlabel(0 (.25) .5)), ///
						legend(off)
				
	//save
		graph export "$figures\fig 6 exim bank frequency histogram.png", as(png) replace

	restore




/*==============================================================================
SECTION 5 ANALYSIS OF THE SUBSAMPLE
==============================================================================*/
use	"$output/Full Dataset", clear
drop if country=="China"

//TABLE 5 Difference-in-means test for subsample and outsample	
	foreach x of var interest maturity grace {
		bysort source: reg `x' subset [iw=amount]
		}	
		
	//data for the "outsample", look at coefficient of the constant
	//data for the subsample, look at the coef of the constant -/+ the coef of the country_subset
	//data for the diff-in-means, look at the coef of the subset
			
	
//FIGURE 7: Portfolio concessionality by country in the subsample
	preserve
	keep if subset==1
	
	//Generate necessary concessionality variables/datapoints
		//Percent Grant Funding
			//generate total lending stats
				bysort country source: egen ttlending_loan=total(amount) if type==2
					gsort country source -type
					replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=.
			
			//total grant stats	
				bysort country source: egen ttlending_grant=total(amount) if type==1
					gsort country source type
					replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=.
				
					replace ttlending_grant=0 if source==1 & country=="Serbia"
					replace ttlending_grant=0 if source==1 & country=="Philippines"
					replace ttlending_grant=0 if source==1 & country=="Papua New Guinea"
					replace ttlending_grant=0 if source==1 & country=="Nigeria"
					replace ttlending_grant=0 if country=="Montenegro"
					replace ttlending_grant=0 if source==1 & country=="Gabon"
					replace ttlending_grant=0 if source==1 & country=="Dominica"
					replace ttlending_grant=0 if source==1 & country=="Costa Rica"
			
			//get weighted percent of grants
					gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))					
				
		//Weighted Means (interest rate, maturity, grace period)
			//create weighted averages for interest, maturity, grace period and grant element
				foreach x of var interest maturity grace grantelement {
					bysort source country: asgen wm_`x' = `x' if info==2, w(amount)
					}

		//Portfolio concessionality	
			//generate nested grant dollar amount within loans by country
				gen nested_grant = wm_grantelement*ttlending_loan if type==2 & info==2
					gsort country source -type -info
					replace nested_grant=nested_grant[_n-1] if nested_grant>=.
			
			//create variable of portfolio concessionality
				gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
					replace concess = 0 if concess<=0
					replace concess = 100 if concess>=100
					format concess %9.2fc
		
	//Create a graph						
		//format data
			//shrink dataset to one observation per country/source and only keep concessionality statistics
				bysort source country: keep if _n==1
				keep source country concess
			
			//gen difference in concessionality by reshaping
				reshape wide concess, i(country) j(source)
				gen diff = concess1-concess0
				
				rename (concess1 concess0) (concess_wb concess_china)
						
			//generate values for the x axis
				//country, alphabetical
				sort country
				gen id=_n
				ssc install labutil
				labmask id, values (country)
					
			//format all data in decimal form
				replace concess_wb=			concess_wb/100
				replace concess_china = 	concess_china/100
				replace diff = 				diff/100
		
		//format graphic
			//set scheme
				set scheme s1mono
			
			//scatter - id (sorted alphabetically)
				graph twoway 	(scatter concess_wb id, msym(circle) mcol("0 103 127")) ///
								(scatter concess_china id, msym(circle) mcol("255 191 63")), ///
								yline(.25 .35, lpattern(dash) lcolor("105 97 88")) ///
								ylab(0 (.20) 1, format(%9.2f) angle(horizontal)) ///
								yti("Portfolio concessionality by country") ///
								xlab(1 (1) 28, valuelabels labs(small) angle(45)) ///
								xlab(6 7 9 16 20, add custom labcolor("220 68 5%150")) ///
								xti(" ") ///
								legend(label(1 "World Bank") label(2 "China")) 	
		
			graph export "$figures\fig 8 scatterplot concessionality.png", as(png) replace
			
	restore

			
					
			
//TABLE 6: Lending Terms of Subset Countries for China, World Bank, and Private Sector
	
	//Generating data on the Private Sector
		//pull private sector data from World Bank International Debt Statistics
			import excel "$input/Data_Extract_From_International_Debt_Statistics (1).xlsx", ///
				sheet("Data") firstrow clear
		
		//reshape data
			destring YR2000 YR2001 YR2002 YR2003 YR2004 YR2005, replace force	
			drop if CountryCode==""	

			reshape long YR, i(CountryName CountryCode SeriesName SeriesCode) j(year)
	
			encode SeriesName, gen(series)
			codebook series
			gen series2=series
			la define series2 1 "Grace" 2 "Interest" 3 "Maturity" 4 "Private commitments" 5 "Total commtiments (publicly guaranteed)"
			label val series2 series2
			drop series
			
			drop SeriesName SeriesCode
			rename YR var
			
			reshape wide var, i( CountryName CountryCode year) j( series2)
			
			rename (var1 var2 var3 var4 var5) (grace interest maturity private_commt total_commt)
			rename CountryName country
			
			save "$output/private sector", replace
	

		//Convert amounts into USD2014
			merge m:m year using "$output/Inflation deflators USD 2014"
			drop _merge total_commt
			destring deflator, replace force
			gen amount_private=private_commt/deflator
		
			format amount_private %15.0fc
			drop private_commt
			
		//gen weighted average for lending variables by amount for time period 2000-2014
			foreach x of var interest maturity grace {
				bysort country: asgen wm_`x' = `x', w(amount)
				}
				
				format wm_interest %9.4fc
				format wm_maturity wm_grace %9.1fc
			
			foreach x of var interest maturity grace {
				tab country, sum (wm_`x') nof
				}	
	
		//create grant element variables, one bounded and one unbounded
			replace wm_interest=wm_interest/100
			
			gen grant_element = (1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
								(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
				la var grant_element "Loan concessionality, unbounded"
			
			gen grant_element2 = grant_element
				la var grant_element2 "Loan concessionality, bounded 0-100"
				replace grant_element2 = 0 if grant_element2<=0
				replace grant_element2= 1.00 if grant_element2>=100
			
			format grant_element grant_element2 %9.4fc
			tab country, sum(grant_element) nof
	
		//final edits to private sector data
			rename(grace interest maturity wm_interest wm_maturity wm_grace grant_element grant_element2) =_p
		
			replace country="Congo, Republic of" if country=="Congo, Rep."
	
			save "$output/private sector", replace
	
	//Get summary statistics for table			
		//For China and World Bank
			use	"$output/Full Dataset", clear
			preserve
			
			drop if country=="China"
			keep if subset==1

			bysort source: sum interest maturity grace grantelement if type==2 [iweight=amount]
		
			restore
			
		//For private sector
			use "$output/private sector", clear
			
			sum interest_p maturity_p grace_p grant_element_p [iweight=amount_private]	


		











