/*==============================================================================
File name: 		Chinese_World_Bank_Lending_Terms_Appendices_20200302_FINAL.do
AUTHOR:			Alysha Gardner

Date Created: 	02/28/2020
Date Updated: 	03/02/2020

Description: 	This program creates descriptive statistics for the appendices of
				"Chinese and World Bank Lending Terms."

Inputs:			"$output/Full Dataset"

Outputs:		

SUMMARY: 		This program creates descriptive statistics for the appendices of
				"Chinese and World Bank Lending Terms." 
				- Appendix 2A	Full Country List with Grant and Loan Financing ///
								by Source
				- Appendix 2B	Summary Statistics by Region
				- Appendix 2C	Summary Statistics by World Bank Lending Category
				- Appendix 2D	Summary Statistics by Income Bracket
				- Appendix 2E	Summary Statistics by Official Chinese Financier
				- Appendix 2F	Summary Statistics for Each Country in the Subsample
					
				


================================================================================
PRELIMINARIES
==============================================================================*/

clear
set more off

//set directory
if "`c(username)'" == "agardner" {
	global root "/Users/agardner/OneDrive - Center for Global Development/Personal/China Development Initiative/Chinese and World Bank Lending Terms"
	}

global data 	"$root/data"
global input	"$root/data/input"
global output	"$root/data/output"
global dofile	"$root/do"
global figures	"$root/figures"
cd "$root"

use	"$output/Full Dataset", clear

drop if country=="China"

//ssc install asgen

/*==============================================================================
APPENDIX A Full Country List with Grant and Loan Financing by Source
==============================================================================*/
use	"$output/Full Dataset", clear
preserve

drop if country=="China"

	//gen statistics of total lending, by loan and by grant
		table country source, contents (sum amount) format(%15.0fc)
			//total sum of lending in the 15-year period by country
		table country type if source==0, contents (sum amount) format (%15.0fc)
			//China financing, broken out by loans and grants
		table country type if source==1, contents (sum amount) format (%15.0fc)
			//World Bank financing, broken out by loans and grants

	//copy all tables to excel spreadsheet to calculate percentages

restore
	
/*==============================================================================
APPENDIX B Summary Statistics by Region
==============================================================================*/
use	"$output/Full Dataset", clear
preserve

drop if country=="China"

	//Total Face Value of Funding & Percent of Total Funding
		table region source, contents (sum amount) format(%15.0fc) row
			//transfer to excel to generate weighted percents
	
	
	//Total number of projects
		tab region source 
	
	
	//Average loan/grant size
		table region source if type==2, contents (mean amount) format(%15.0fc)	//loan
		table region source if type==1, contents (mean amount) format(%15.0fc)	//grant
	
	
	//Percent Grant Funding
		//generate total lending stats
			bysort region source: egen ttlending_loan=total(amount) if type==2
				gsort region source -type
				replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=.
					
		//total grant stats				
			bysort region source: egen ttlending_grant=total(amount) if type==1
				gsort region source type
				replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=.
						
		//weighted percent of grants
			gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
			tab region source, sum(per_grant) nof
	
	
	//Weighted Means (interest rate, maturity, grace period)
		//create weighted averages for interest, maturity, and grace period
			foreach x of varlist interest maturity grace {
				bysort source region: asgen wm_`x' = `x', w(amount)
				}
		
		//format stats for rounding		
			format wm_interest %9.4fc
			format wm_maturity wm_grace %9.1fc	
				
		//find weighted average statistics by type
			foreach y of varlist wm_interest wm_maturity wm_grace {
				tab region source if type==2, sum (`y') nof nost
				}  
	
	//Loan concessionality (derived from weighted means)
		gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
							(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
			la var loan_concess "Grant element by region, unbounded"
			
		gen loan_concess2 = 100*loan_concess
			la var loan_concess2 "Grant element by region, bounded 0-100"	
			format loan_concess2 %9.2fc
			replace loan_concess2 = 0 if loan_concess<=0
			replace loan_concess2 = 100 if loan_concess>=1
			
		tab region source, sum (loan_concess2) nost nof
	
	
	//Portfolio concessionality

		//generate Nested Grant dollar amount
			gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
				gsort region source -type
				replace nested_grant=nested_grant[_n-1] if nested_grant>=.
		
		//generate Portfolio Concessionality
			gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
				replace concess = 0 if concess<=0
				replace concess = 100 if concess>=100
				format concess %9.2fc
		
		//get stats
				tab region source, sum(concess) nof nost

restore


/*==============================================================================
APPENDIX C Summary Statistics by World Bank Lending Category
==============================================================================*/
use	"$output/Full Dataset", clear
preserve

drop if country=="China"

	//Adjustments to World Bank lending group status
		replace lendgrp=1	if country==	"Kosovo"						//IDA
		replace lendgrp=1 	if country==	"Vanuatu"						//IDA
		replace lendgrp=1	if country==	"Montenegro"	& year<=2005	//IDA
		replace lendgrp=3   if country==	"Nauru"							//IBRD
	
	
	//Total Face Value of Funding & Percent of Total Funding
		table lendgrp source, contents (sum amount) format(%15.0fc) row
			//transfer to excel to generate weighted percents
	
	
	//Total number of projects
		tab lendgrp source 
	
	
	//Average loan/grant size
		table lendgrp source if type==2, contents (mean amount) format(%15.0fc)	//loan
		table lendgrp source if type==1, contents (mean amount) format(%15.0fc)	//grant
	
	
	//Percent Grant Funding
		//generate total lending stats
			bysort lendgrp source: egen ttlending_loan=total(amount) if type==2
				gsort lendgrp source -type
				replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=.
					
		//total grant stats				
			bysort lendgrp source: egen ttlending_grant=total(amount) if type==1
				gsort lendgrp source type
				replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=.
						
		//weighted percent of grants
			gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
			tab lendgrp source, sum(per_grant) nof nost
	
	
	//Weighted Means (interest rate, maturity, grace period)
		//create weighted averages for interest, maturity, and grace period
			foreach x of varlist interest maturity grace {
				bysort source lendgrp: asgen wm_`x' = `x', w(amount)
				}
		
		//format stats for rounding		
			format wm_interest %9.4fc
			format wm_maturity wm_grace %9.1fc	
				
		//find weighted average statistics by type
			foreach y of varlist wm_interest wm_maturity wm_grace {
				tab lendgrp source if type==2, sum (`y') nof nost
				}  
	
	
	//Loan concessionality (derived from weighted means)
			gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
								(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
				la var loan_concess "Grant element by lending group, unbounded"
			
			gen loan_concess2 = 100*loan_concess
				la var loan_concess2 "Grant element by lending group, bounded 0-100"
				format loan_concess2 %9.2fc
				replace loan_concess2 = 0 if loan_concess<=0
				replace loan_concess2 = 100 if loan_concess>=1
		
			tab lendgrp source, sum (loan_concess2) nof nost
	
	
	//Portfolio concessionality
	
			//generate Nested Grant dollar amount
				gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
					gsort lendgrp source -type
					replace nested_grant=nested_grant[_n-1] if nested_grant>=.
			
			//create variable of portfolio concessionality
				gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
					replace concess = 0 if concess<=0
					replace concess = 100 if concess>=100
					format concess %9.2fc
		
			//get stats
				tab lendgrp source, sum(concess) nof nost
				
restore


/*==============================================================================
APPENDIX D Summary Statistics by Income Bracket
==============================================================================*/
use	"$output/Full Dataset", clear
preserve

drop if country=="China"

	//Total Face Value of Funding & Percent of Total Funding
		table income source, contents (sum amount) format(%15.0fc) row
			//transfer to excel to generate weighted percents
	
	
	//Total number of projects
		tab income source 
		
	
	//Average loan/grant size
		table income source if type==2, contents (mean amount) format(%15.0fc)
		table income source if type==1, contents (mean amount) format(%15.0fc)
	
	
	//Percent Grant Funding
		//generate total lending stats
			bysort income source: egen ttlending_loan=total(amount) if type==2
				gsort income source -type
				replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=.
					
		//total grant stats				
			bysort income source: egen ttlending_grant=total(amount) if type==1
				gsort income source type
				replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=.
						
		//weighted percent of grants
			gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
			tab income source, sum(per_grant) nof nost
	
	
	//Weighted Means (interest rate, maturity, grace period)
		//create weighted averages for interest, maturity, and grace period
			foreach x of varlist interest maturity grace {
				bysort source income: asgen wm_`x' = `x', w(amount)
				}
		
		//format stats for rounding		
			format wm_interest %9.4fc
			format wm_maturity wm_grace %9.1fc	
				
		//find weighted average statistics by type
			foreach y of varlist wm_interest wm_maturity wm_grace {
				tab income source if type==2, sum (`y') nof nost
				}  
	
	
	//Loan concessionality (derived from weighted means)
			gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
								(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
				la var loan_concess "Grant element by income, unbounded"
				
			gen loan_concess2 = 100*loan_concess
				la var loan_concess2 "Grant element by income, bounded 0-100"
				format loan_concess2 %9.2fc
				replace loan_concess2 = 0 if loan_concess<=0
				replace loan_concess2 = 100 if loan_concess>=1
		
			tab income source, sum (loan_concess2) nof nost
	
	
	//Portfolio concessionality
	
			//generate Nested Grant dollar amount
				gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
					gsort income source -type
					replace nested_grant=nested_grant[_n-1] if nested_grant>=.
			
			//create variable of portfolio concessionality
				gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
					replace concess = 0 if concess<=0
					replace concess = 100 if concess>=100
					format concess %9.2fc
			
			//get stats
				tab income source, sum(concess) nof nost

restore


/*==============================================================================
APPENDIX E Summary Statistics by Official Chinese Financier
==============================================================================*/
use	"$output/Full Dataset", clear

//General statistics by LENDER TYPE
	preserve

	drop if country=="China"
	drop if source==1			//World Bank

	
	//Total Face Value of Funding & Percent of Total Funding
		table lender, contents (sum amount) format(%15.0fc) row
			//transfer to excel to generate weighted percents
	
	
	//Total number of projects
		tab lender 
	
	
	//Average loan/grant size
		table lender if type==2, contents (mean amount) format(%15.0fc) //loan
		table lender if type==1, contents (mean amount) format(%15.0fc) //grant
		
		
	//Percent Grant Funding
		//gen total lending stats
			bysort lender: egen ttlending_loan=total(amount) if type==2
				gsort lender -type
				replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=. & lender==lender[_n-1]
					
		//total grant stats				
			bysort lender: egen ttlending_grant=total(amount) if type==1
				gsort lender type
				replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=. & lender==lender[_n-1]
				replace ttlending_grant=0 if lender==3 | lender==4	//SOE or SOB (no grants, only loans)
					
		//get weighted percent of grants
			gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
			tab lender, sum(per_grant) nof nost

	
	//Weighted Means (interest rate, maturity, grace period)
		//create weighted averages for interest, maturity, and grace period
			foreach x of varlist interest maturity grace {
				bysort lender: asgen wm_`x' = `x', w(amount)
				}
		
		//format stats for rounding		
			format wm_interest %9.4fc
			format wm_maturity wm_grace %9.1fc	
				
		//find weighted average statistics by type
			foreach y of varlist wm_interest wm_maturity wm_grace {
				table lender if type==2, contents(mean `y')
				}  
				
	
	//Loan concessionality (derived from weighted means)
			gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
								(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
				la var loan_concess "Grant element by lender type, unbounded"
		
			gen loan_concess2 = 100*loan_concess
				la var loan_concess2 "Grant element by lender type, bounded 0-100"
				format loan_concess2 %9.2fc
				replace loan_concess2 = 0 if loan_concess<=0
				replace loan_concess2 = 100 if loan_concess>=1
		
			table lender if type==2, c(mean loan_concess2) 
	
	//Portfolio concessionality
	
			//generate Nested Grant dollar amount
				gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
					gsort lender -type
					replace nested_grant=nested_grant[_n-1] if nested_grant>=.
			
			//create variable of portfolio concessionality
				gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
					replace concess = 0 if concess<=0
					replace concess = 100 if concess>=100
					format concess %9.2fc
			
			//get stats
				tab lender, sum(concess) nof nost

	restore



//Adjusted general statistics by for GOV AGENCY without Mauritius outlier
	preserve

	drop if country=="China"
	drop if source==1			//World Bank
	
	keep if lender==1			//Government Agency
	drop if id=="20419"			//Mauritius outlier
				
	//Average loan/grant size
		table lender if type==2, contents (mean amount) format(%15.0fc) //loan
				
	
	//Percent Grant Funding
		//generate total lending stats
			bysort lender: egen ttlending_loan=total(amount) if type==2
				gsort lender -type
				replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=. & lender==lender[_n-1]
					
		//total grant stats				
			bysort lender: egen ttlending_grant=total(amount) if type==1
				gsort lender type
				replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=. & lender==lender[_n-1]
				replace ttlending_grant=0 if lender==3 | lender==4
					
		//get weighted percent of grants
			gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
			tab lender, sum(per_grant) nof nost
				
	restore

	
//Statistics by for CHINA DEVELOPMENT BANK and CHINA EXIM BANK
		
	preserve

	drop if country=="China"
	drop if source==1			//World Bank
	
	keep if lender_d==4|lender_d==5		//CDB and China EximBank


	//Total Face Value of Funding & Percent of Total Funding
		table lender_d, contents (sum amount) format(%15.0fc) row
			//transfer to excel to generate weighted percents
	
	
	//Total number of projects
		tab lender_d 
	
	
	//Average loan/grant size
		table lender_d if type==2, contents (mean amount) format(%15.0fc) //loan
		table lender_d if type==1, contents (mean amount) format(%15.0fc) //grant
	
	
	//Percent Grant Funding
		//generate total lending stats
			bysort lender_d: egen ttlending_loan=total(amount) if type==2
				gsort lender_d -type
				replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=. & lender_d==lender_d[_n-1]
					
		//total grant stats				
			bysort lender_d: egen ttlending_grant=total(amount) if type==1
				gsort lender_d type
				replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=. & lender_d==lender_d[_n-1]

		//weighted percent of grants
			gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
			tab lender_d, sum(per_grant) nof nost

	
	//Weighted Means (interest rate, maturity, grace period)
		//create weighted averages for interest, maturity, and grace period
			foreach x of varlist interest maturity grace {
				bysort lender_d: asgen wm_`x' = `x', w(amount)
				}
		
		//format stats for rounding		
			format wm_interest %9.4fc
			format wm_maturity wm_grace %9.1fc	
				
		//find weighted average statistics by type
			foreach y of varlist wm_interest wm_maturity wm_grace {
				table lender_d if type==2, contents(mean `y')
				}  
				
	
	//Loan concessionality (derived from weighted means)
		gen loan_concess = 	(1 - ((wm_interest/2)/((1.05^0.5)-1)))* ///
							(1 - (((1/((1+((1.05^0.5)-1))^(2*wm_grace)))-(1/((1+((1.05^0.5)-1))^(2*wm_maturity))))/(((1.05^0.5)-1)*((2*wm_maturity)-(2*wm_grace)))))
			la var loan_concess "Grant element by lender, unbounded"
			
		gen loan_concess2 = 100*loan_concess
			la var loan_concess2 "Grant element by lender, bounded 0-100"
			format loan_concess2 %9.2fc
			replace loan_concess2 = 0 if loan_concess<=0
			replace loan_concess2 = 100 if loan_concess>=1
		
		table lender_d if type==2, c(mean loan_concess2) 
	
	//Portfolio concessionality
	
		//generate nested grant dollar amount within loans by country
			gen nested_grant = (loan_concess2/100)*ttlending_loan if type==2
			gsort lender_d -type
			replace nested_grant=nested_grant[_n-1] if nested_grant>=.
			
		//create variable of portfolio concessionality
			gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
			replace concess = 0 if concess<=0
			replace concess = 100 if concess>=100
			format concess %9.2fc
	
		//get stats
			tab lender_d, sum(concess) nof nost

restore	


/*==============================================================================
APPENDIX F Summary Statistics for Each Country in the Subsample
==============================================================================*/
use	"$output/Full Dataset", clear
preserve

drop if country=="China"
drop if source==1			//World Bank

keep if subset==1


	//Total no. of projects
		tab country source

	
	//Total lending
		table country source, contents (sum amount) format(%15.0fc)
	
	
	//Average loan/grant size
		table country source if type==2, contents (mean amount) format(%15.0fc) //avg loan size
		table country source if type==1, contents (mean amount) format(%15.0fc) //avg grant size
	
	//Percent Grant Funding
		//generate total lending stats
			bysort country source: egen ttlending_loan=total(amount) if type==2
				gsort country source -type
				replace ttlending_loan=ttlending_loan[_n-1] if ttlending_loan>=.
		
		//total grant stats	
			bysort country source: egen ttlending_grant=total(amount) if type==1
				gsort country source type
				replace ttlending_grant=ttlending_grant[_n-1] if ttlending_grant>=.
			
				replace ttlending_grant=0 if source==1 & country=="Serbia"
				replace ttlending_grant=0 if source==1 & country=="Philippines"
				replace ttlending_grant=0 if source==1 & country=="Papua New Guinea"
				replace ttlending_grant=0 if source==1 & country=="Nigeria"
				replace ttlending_grant=0 if country=="Montenegro"
				replace ttlending_grant=0 if source==1 & country=="Gabon"
				replace ttlending_grant=0 if source==1 & country=="Dominica"
				replace ttlending_grant=0 if source==1 & country=="Costa Rica"
		
		//get weighted percent of grants
				gen per_grant=100*(ttlending_grant/(ttlending_grant+ttlending_loan))
				tab country source, sum(per_grant) nost nof
						
			
	//Weighted Means (interest rate, maturity, grace period)
		//create weighted averages for interest, maturity, grace period and grant element
			foreach x of var interest maturity grace grantelement {
				bysort source country: asgen wm_`x' = `x' if info==2, w(amount)
				}
		//format stats for rounding		
			format wm_interest wm_grantelement %9.4fc
			format wm_maturity wm_grace %9.1fc
		
		//find weighted average statistics by type
			foreach x of var interest maturity grace grantelement {
				tab country source if type==2 & info==2, sum (wm_`x') nof nost
				}
	
	
	//Portfolio concessionality
	
		//generate nested grant dollar amount within loans by country
			gen nested_grant = wm_grantelement*ttlending_loan if type==2 & info==2
				gsort country source -type -info
				replace nested_grant=nested_grant[_n-1] if nested_grant>=.
		
		//create variable of portfolio concessionality
			gen concess= 100*((ttlending_grant + nested_grant)/(ttlending_grant + ttlending_loan))
				replace concess = 0 if concess<=0
				replace concess = 100 if concess>=100
				format concess %9.2fc
		
		//get stats
			tab country source, sum(concess) nof nost
				
restore
	



				
				
				
				
				
				
				
				
				
				
				
				
				
				
				
				
				









