/*==============================================================================
File name: 		Chinese_World_Bank_Lending_Terms_Database_Creation_20200228_FINAL.do
AUTHOR:			Alysha Gardner

Date Created: 	02/04/2020
Date Updated: 	02/28/2020

Description: 	This program creates a unique database of World Bank and Chinese 
				lending from 2000-2014 by merging three datasets and generating
				comparable variables on lending terms.

Inputs:			"$input/GlobalChineseOfficialFinanceDataset_v1.0.xlsx"
				"$input/IDA_Statement_of_Credits_and_Grants__-_Latest_Available_Snapshot"
				"$input/IBRD_Statement_of_loans_-_Latest_Available_Snapshot"
				
				"$input/Historical LIBOR rates.xls"	
				"$input/World Bank FLR"
				"$input/Historical Income Categories.xls"
				"$input/Historical Lending Categories.xls"

Outputs:		"$output/Full Dataset"
				
				"$output/AidData clean"
				"$output/World Bank clean"
				"$output/IDA clean"
				"$output/IBRD clean"	

				"$output/Inflation deflators USD 2014"
				"$output/historical libor rates"	
				"$output/World Bank FLR"
				"$output/Historical income categories", replace
				"$output/Historical lending categories", replace

SUMMARY: 		This program creates a unique database of World Bank and Chinese 
				lending from 2000-2014 by merging three datasets and generating
				comparable variables on lending terms.
					1. Extract and format relevant data from AidData					
					2. Create deflators and modifiers 
						- Deflators using AidData methodology to standardize 
							World Bank loan/grant amounts to USD_2014
						- Use LIBOR rates and World Bank lending policy to 
							approximate interest rates for IBRD flexible loans
							(fixed and variable spread)
					3. Extract and formate relevant data from IDA Statement of
						Credits and Grants
					4. Extract and format relevant data from IBRD Statement of Loans
					5. Merge Aiddata and World Bank observations into a single database
						- Calculate additional relevant variables

================================================================================
PRELIMINARIES
==============================================================================*/

clear
set more off

//set directory
if "`c(username)'" == "agardner" {
	global root "/Users/agardner/OneDrive - Center for Global Development/Personal/China Development Initiative/Chinese and World Bank Lending Terms"
	}

global data 	"$root/data"
global input	"$root/data/input"
global output	"$root/data/output"
global dofile	"$root/do"
global figures	"$root/figures"
cd "$root"


/*==============================================================================
AIDDATA GLOBAL CHINESE OFFICIAL FINANCE DATASET
==============================================================================*/
	//import AidData dataset
		import excel "$input/GlobalChineseOfficialFinanceDataset_v1.0.xlsx", firstrow clear

	//remove variables that do not contribute to study objectives
		drop umbrella implementing_agency description flow_class intent crs_sector_code ///
		crs_sector_name sources sources_count recipient_agencies recipient_agencies_count ///
		start_actual start_planned end_actual end_planned year_uncertain all_recipients ///
		recipient_count recipient_cow_code recipient_oecd_code recipient_oecd_name ///
		recipient_un_code recipient_imf_code line_of_credit is_cofinanced is_ground_truthing ///
		location_details contacts source_triangulation field_completeness status currency ///
		exchange_rates_used grant_element	
	
	//remove observations that fall outside the study objectives (space, status, etc)
		
		//drop all observations that are regional or multi-country loans
			rename recipient_condensed country
			sort country
			drop if 	country=="Africa, regional" ///
						|country=="Asia, regional" ///
						|country=="Caribbean, regional" ///
						|country=="Europe, regional" ///
						|country=="Middle East, regional" ///
						|country=="Oceania, regional" ///
						|country=="South America, regional" ///
						|country=="Southeast Asia, regional" //59 obs deleted

		//drop all that are not "recommended for research" 
			/*This field identifies projects that AidData recommends including for normal 
				research & financial analysis. It is equal to "TRUE" for all projects 
				except for those that are marked as umbrella projects, pledges, cancelled, 
				or suspended projects. We recommend excluding the projects marked "FALSE" 
				because the umbrella projects and projects with a status of pledged, 
				cancelled, or suspended likely represent double counting or would lead to 
				including flows that were never fully committed/implemented. This field is 
				meant to make it easier for users to clearly identify the set of projects 
				that we recommend using to better understand the volume and composition of 
				Chinese Official Finance. */
			drop if recommended_for_research==0 //1,093 obs deleted
			drop recommended_for_research
		
		//drop non-comparable financing types (analysis restricted to loans and grants)
			drop if 	flow=="Debt forgiveness" ///
						|flow=="Debt rescheduling" ///
						|flow=="Free-standing technical assistance" ///
						|flow=="Scholarships/training in the donor country" ///
						|flow=="Strategic/Supplier Credit" ///
						|flow=="Vague TBD" //245 obs deleted	
	
		//drop if there is no value for the loan/grant amount
			destring usd_defl_2014 usd_current, replace
			destring amount, replace
			drop if amount==. //1,132 obs deleted 
	
	
	//standardize variables for use in merged dataset
		
		//amount		
			drop amount
			rename usd_defl_2014 amount
			la var amount "Value of grant/loan in USD 2014"			
		
		//cofinance
			rename cofinancing_agency cofinance
			la var cofin "Cofinancing institution(s)" 
		
		//country
			la var country "Country"		
		
		//countrycode
			rename recipient_iso2 countrycode
			la var countrycode "Country Code"
			format %5s countrycode		
		
		//deflator
			rename deflators_used deflator
			la var deflator "Currency deflator (AidData methodology)"		

		//grace
			rename grace_period grace
			destring grace, replace
			la var grace "Grace period, years"		
		
		//id
			rename project_id id
			la var id "Unique identifier"
					
		//interest
			rename interest_rate interest
			destring interest , replace
			replace interest=0 if loan_type=="Interest-Free"
			drop loan_type
			la var interest "Interest Rate"		

		//lender
			rename funding_agency lender
			la var lender "Lending institution(s)"		
		
		//maturity
			destring maturity, replace
			la var maturity "Maturity length, years"		
		
		//originalamount
			rename usd_current originalamount
			la var originalamount "Original Principal Amount (USD) in agreement signing year"			
		
		//projectname
			rename title projectname
			la var projectname "Project Name"		
		
		//region
			gen region="Blank"
			replace region = "EAST ASIA AND PACIFIC" 		if recipient_iso3 == "ASM" | recipient_iso3== "AUS" ///
																| recipient_iso3== "BRN" | recipient_iso3== "KHM" ///
																|recipient_iso3== "CHN" | recipient_iso3== "FJI" ///
																| recipient_iso3== "PYF" | recipient_iso3== "GUM" ///
																| recipient_iso3== "HKG" | recipient_iso3== "IDN" ///
																| recipient_iso3== "JPN" | recipient_iso3== "KIR" ///
																| recipient_iso3== "PRK" | recipient_iso3== "KOR" ///
																| recipient_iso3== "LAO" | recipient_iso3== "MAC" ///
																| recipient_iso3== "MYS" | recipient_iso3== "MHL" ///
																| recipient_iso3== "FSM" | recipient_iso3== "MNG" ///
																| recipient_iso3== "MMR" | recipient_iso3== "NRU" ///
																| recipient_iso3== "NCL" | recipient_iso3== "NZL" ///
																| recipient_iso3== "MNP" | recipient_iso3== "PLW" ///
																| recipient_iso3== "PNG" | recipient_iso3== "PHL" ///
																| recipient_iso3== "WSM" | recipient_iso3== "SGP" ///
																| recipient_iso3== "SLB" | recipient_iso3== "TWN" ///
																| recipient_iso3== "THA" | recipient_iso3== "TLS" ///
																| recipient_iso3== "TON" | recipient_iso3== "TUV" ///
																| recipient_iso3== "VUT" | recipient_iso3== "VNM"
			replace region = "EUROPE AND CENTRAL ASIA" 		if recipient_iso3 == "ALB" | recipient_iso3== "AND" ///
																| recipient_iso3== "ARM" | recipient_iso3== "AUT" ///
																| recipient_iso3== "AZE" | recipient_iso3== "BLR" ///
																| recipient_iso3== "BEL" | recipient_iso3== "BIH" ///
																| recipient_iso3== "BGR" | recipient_iso3== "CHI" ///
																| recipient_iso3== "HRV" | recipient_iso3== "CYP" ///
																| recipient_iso3== "CZE" | recipient_iso3== "DNK" ///
																| recipient_iso3== "EST" | recipient_iso3== "FRO" ///
																| recipient_iso3== "FIN" | recipient_iso3== "FRA" ///
																| recipient_iso3== "GEO" | recipient_iso3== "DEU" ///
																| recipient_iso3== "GIB" | recipient_iso3== "GRC" ///
																| recipient_iso3== "GRL" | recipient_iso3== "HUN" ///
																| recipient_iso3== "ISL" | recipient_iso3== "IRL" ///
																| recipient_iso3== "IMN" | recipient_iso3== "ITA" ///
																| recipient_iso3== "KAZ" | recipient_iso3== "XKX" ///
																| recipient_iso3== "KGZ" | recipient_iso3== "LVA" ///
																| recipient_iso3== "LIE" | recipient_iso3== "LTU" ///
																| recipient_iso3== "LUX" | recipient_iso3== "MKD" ///
																| recipient_iso3== "MDA" | recipient_iso3== "MCO" ///
																| recipient_iso3== "MNE" | recipient_iso3== "NLD" ///
																| recipient_iso3== "NOR" | recipient_iso3== "POL" ///
																| recipient_iso3== "PRT" | recipient_iso3== "ROU" ///
																| recipient_iso3== "RUS" | recipient_iso3== "SMR" ///
																| recipient_iso3== "SRB" | recipient_iso3== "SVK" ///
																| recipient_iso3== "SVN" | recipient_iso3== "ESP" ///
																| recipient_iso3== "SWE" | recipient_iso3== "CHE" ///
																| recipient_iso3== "TJK" | recipient_iso3== "TUR" ///
																| recipient_iso3== "TKM" | recipient_iso3== "UKR" ///
																| recipient_iso3== "GBR" | recipient_iso3== "UZB"
			replace region = "LATIN AMERICA AND CARIBBEAN" 	if recipient_iso3 == "ATG"| recipient_iso3=="ARG" ///
																| recipient_iso3== "ABW"| recipient_iso3== "BHS" ///
																| recipient_iso3== "BRB"| recipient_iso3== "BLZ" ///
																| recipient_iso3== "BOL"| recipient_iso3== "BRA" ///
																| recipient_iso3== "VGB"| recipient_iso3== "CYM" ///
																| recipient_iso3== "CHL"| recipient_iso3== "COL" ///
																| recipient_iso3== "CRI"| recipient_iso3== "CUB" ///
																| recipient_iso3== "CUW"| recipient_iso3== "DMA" ///
																| recipient_iso3== "DOM"| recipient_iso3== "ECU" ///
																| recipient_iso3== "SLV"| recipient_iso3== "GRD" ///
																| recipient_iso3== "GTM"| recipient_iso3== "GUY" ///
																| recipient_iso3== "HTI"| recipient_iso3== "HND" ///
																| recipient_iso3== "JAM"| recipient_iso3== "MEX" ///
																| recipient_iso3== "NIC"| recipient_iso3== "PAN" ///
																| recipient_iso3== "PRY"| recipient_iso3== "PER" ///
																| recipient_iso3== "PRI"| recipient_iso3== "SXM" ///
																| recipient_iso3== "KNA"| recipient_iso3== "LCA" ///
																| recipient_iso3== "MAF"| recipient_iso3== "VCT" ///
																| recipient_iso3== "SUR"| recipient_iso3== "TTO" ///
																| recipient_iso3== "TCA"| recipient_iso3== "URY" ///
																| recipient_iso3== "VEN"| recipient_iso3== "VIR" 
			replace region = "MIDDLE EAST AND NORTH AFRICA" if recipient_iso3 == "DZA"| recipient_iso3=="BHR" ///
																| recipient_iso3== "DJI"| recipient_iso3== "EGY" ///
																| recipient_iso3== "IRN"| recipient_iso3== "IRQ" ///
																| recipient_iso3== "ISR"| recipient_iso3== "JOR" ///
																| recipient_iso3== "KWT"| recipient_iso3== "LBN" ///
																| recipient_iso3== "LBY"| recipient_iso3== "MLT" ///
																| recipient_iso3== "MAR"| recipient_iso3== "OMN" ///
																| recipient_iso3== "QAT"| recipient_iso3== "SAU" ///
																| recipient_iso3== "SYR"| recipient_iso3== "TUN" ///
																| recipient_iso3== "ARE"| recipient_iso3== "PSE" ///
																| recipient_iso3== "YEM"
			replace region = "SOUTH ASIA" 					if recipient_iso3 == "AFG"| recipient_iso3=="BGD" ///
																| recipient_iso3== "BTN"| recipient_iso3== "IND" ///
																| recipient_iso3== "MDV"| recipient_iso3== "NPL" ///
																| recipient_iso3== "PAK"| recipient_iso3== "LKA"
			replace region = "AFRICA" 						if recipient_iso3 == "AGO" | recipient_iso3== "BEN" ///
																| recipient_iso3== "BWA"| recipient_iso3== "BFA" ///
																| recipient_iso3== "BDI"| recipient_iso3== "CPV" ///
																| recipient_iso3== "CMR"| recipient_iso3== "CAF" ///
																| recipient_iso3== "TCD"| recipient_iso3== "COM" ///
																| recipient_iso3== "COD"| recipient_iso3== "COG" ///
																| recipient_iso3== "CIV"| recipient_iso3== "GNQ" ///
																| recipient_iso3== "ERI"| recipient_iso3== "ETH" ///
																| recipient_iso3== "GAB"| recipient_iso3== "GMB" ///
																| recipient_iso3== "GHA"| recipient_iso3== "GIN" ///
																| recipient_iso3== "GNB"| recipient_iso3== "KEN" ///
																| recipient_iso3== "LSO"| recipient_iso3== "LBR" ///
																| recipient_iso3== "MDG"| recipient_iso3== "MWI" ///
																| recipient_iso3== "MLI"| recipient_iso3== "MRT" ///
																| recipient_iso3== "MUS"| recipient_iso3== "MOZ" ///
																| recipient_iso3== "NAM"| recipient_iso3== "NER" ///
																| recipient_iso3== "NGA"| recipient_iso3== "RWA" ///
																| recipient_iso3== "STP"| recipient_iso3== "SEN" ///
																| recipient_iso3== "SYC"| recipient_iso3== "SLE" ///
																| recipient_iso3== "SOM"| recipient_iso3== "ZAF" ///
																| recipient_iso3== "SSD"| recipient_iso3== "SDN" ///
																| recipient_iso3== "SWZ"| recipient_iso3== "TZA" ///
																| recipient_iso3== "TGO"| recipient_iso3== "UGA" ///
																| recipient_iso3== "ZMB"| recipient_iso3== "ZWE"
			replace region = "EAST ASIA AND PACIFIC" 		if region=="Blank" 
						//7 changes made for Cook Islands and Niue, both of which are associated with New Zealand
			drop recipient_region recipient_iso3
			la var region "Region"		
		
		//source
			rename donor source
			label variable source "World Bank or China"		
		
		//type
			gen type=1 if flow=="Grant"
			replace type=2 if flow=="Loan (excluding debt rescheduling)" | flow=="Export credits"
			la var type "Loan or Grant"

		//type_d
			rename flow type_d
			la var type_d "Loan or Grant, detailed"		
		
		//year
			la var year "Year of agreement signing date"
				
		//order variables
			order id source country countrycode year type type_d amount deflator ///
				originalamount interest	maturity grace region lender cofinance projectname 
		
	//save file of cleaned IDA lending terms data
			save "$output/AidData clean", replace	
		
/*==============================================================================
DEFLATORS AND MODIFIERS
==============================================================================*/

/*Create deflators using AidData methodology to standardize World Bank loan/grant 
	amounts to USD_2014*/

	//import dataset
		//use "$output/AidData clean", clear
	
	//keep relevant obs/vars
		drop if deflator==" " | deflator==""
		
		drop id source country countrycode type type_d amount originalamount interest ///
			maturity grace region lender cofinance projectname
	
	//keep one deflator observation per year
		gsort year -deflator
		by year: keep if _n==1
		
	//save
		save "$output/Inflation deflators USD 2014", replace
	
		
/* Create modifiers using LIBOR rates and Bank policy to generate approximate
	interest rates for IBRD flexible loan rates, designated "FSL" in the data.
	(Includes both fixed spread loans and IBRD flexible loans that have either
	fixed spread or variable spread terms).
	
	Fixed rate interest loans (which make up 80% of IBRD loans in our sample) are 
	marked as a "0" in the original IBRD dataset, which means that out of necessity
	we will need to rely on other data sources to generate reliable interest rate 
	observations. From the World Bank website, "the IBRD currently offers only one
	loan, the IBRD Flexible Loan or IFL with a choice of two spreads - Fixed or 
	Variable." These loans are LIBOR- and currency-based products. 
	
	IBRD typically uses a floating market interst rate (six-month LIBOR) plus a 
	spread that is fixed over the life of the loan.
	
	When a Chinese loan (in the AidData dataset) is provided at LIBOR+fixed spread,
	AidDAta identifies the LIBOR rate at the time the loan is approved and then 
	applies that rate (plus the fixed spread) over the full life of the loan, 
	notwithstanding the fact that LIBOR rate is floating over the full life of the
	loan. For comparability purposes, we will take the same approach for World Bank
	IBRD loans.
	
	To generate interest rates for IBRD loans, we need to know the following:
		- The loan recipient's country grouping (ABCD) at the time of the loan issuance
		- The 6-month LIBOR rate at the time of loan issuance
		- The maturity lenth of the loan
		- See https://treasury.worldbank.org/en/about/unit/treasury/ibrd-financial-products/lending-rates-and-fees 
		*/
	
	//LIBOR data (from FRED)
		//input LIBRO data
			import excel "$input/Historical LIBOR rates.xls", sheet("FRED Graph (2)") firstrow clear
	
		//format LIBOR data for merging
			rename (observation_date USD6MTD156N) (agreementsigningdate libor)
			replace libor=libor[_n-1] if missing(libor)
			save "$output/historical libor rates", replace		
			
			
	//WB lending rate data(by recipient country grouping and maturity of loan)
		//input WB data
			import excel "$input/World Bank FLR", sheet("FLR") firstrow clear
		
		//clean WB data
			la var FSL08 	"Fixed spread loan, maturity < 8 years"
			la var FSL810 	"Fixed spread loan, maturity 8+ to 10 years"
			la var FSL1012 	"Fixed spread loan, maturity 10+ to 12 years"			
			la var FSL1215 	"Fixed spread loan, maturity 12+ to 15 years"			
			la var FSL1518 	"Fixed spread loan, maturity 15+ to 18 years"			
			la var FSL1820 	"Fixed spread loan, maturity 18+ years"			
			la var VSL08 	"Variable spread loan, maturity < 8 years"			
			la var VSL810 	"Variable spread loan, maturity 8+ to 10 years"
			la var VSL1012 	"Variable spread loan, maturity 10+ to 12 years"			
			la var VSL1215 	"Variable spread loan, maturity 12+ to 15 years"			
			la var VSL1518 	"Variable spread loan, maturity 15+ to 18 years"				
			la var VSL1820 	"Variable spread loan, maturity 18+ years"	
			
			rename YearAdjustedPricingCategory countrygrp
			la var countrygrp "World Bank year-adjusted pricing category (A B C or D)"
			
			rename Year year
			rename Country country		
	
		//generate premiums as an average of the rate for fixed and variable spread loans
			gen premium8 = 	(FSL08 + VSL08)/2
			gen premium10 = (FSL810 + VSL810)/2			
			gen premium12 = (FSL1012 + VSL1012)/2			
			gen premium15 = (FSL1215 + VSL1215)/2			
			gen premium18 = (FSL1518 + VSL1518)/2			
			gen premium20= 	(FSL1820 + VSL1820)/2
			
			la var premium8 	"IBRD flexible loan (IFL) premium, maturity < 8 years (avg of VSL and FSL)"
			la var premium10 	"IFL premium, maturity 8+ to 10 years (avg of VSL and FSL)"
			la var premium12 	"IFL flexible loan premium, maturity 10+ to 12 years (avg of VSL and FSL)"
			la var premium15 	"IFL flexible loan premium, maturity 12+ to 15 years (avg of VSL and FSL)"
			la var premium18 	"IFL flexible loan premium, maturity 15+ to 18 years(avg of VSL and FSL)"
			la var premium20 	"IFL flexible loan premium, maturity 18+ years (avg of VSL and FSL)"
			

		//save data
			save "$output/World Bank FLR", replace
		
			

/*==============================================================================
IDA STATEMENT OF CREDITS AND GRANTS
==============================================================================*/

	//import WB/IDA dataset
		import delimited "$input/IDA_Statement_of_Credits_and_Grants__-_Latest_Available_Snapshot", clear
	
	//remove variables that do not contribute to study objectives
		drop ïendofperiod borrower currencyofcommitment cancelledamount undisbursedamount ///
		disbursedamount repaidtoida duetoida exchangeadjustment borrowersobligation ///
		sold3rdparty repaid3rdparty due3rdparty creditsheld lastdisbursementdate
		
		//use "agreement signing date" as year unless missing, then use "board approval date"
			sort agreementsigningdate
			replace agreementsigningdate=boardapprovaldate if agreementsigningdate=="" //141 obs switched
			drop boardapprovaldate closeddatemostrecent
	
	//remove observations that fall outside the study objectives (time, space, status, etc)
		
		//drop all observations that are regional, multi-country, or "other" (MIGA/IFC) loans
			drop if country=="Africa" ///
					|country=="Central Africa" ///
					|country=="Central America" ///
					|country=="Central Asia" ///
					|country=="Pacific Islands" ///
					|country=="Western Africa" ///
					|country=="Mekong" ///
					|country=="Caribbean"  //84 obs deleted	
			
			drop if region=="OTHER"	//7 obs deleted
		
		//drop all dates before 2000 and after 2014
			
			//convert dates from strings to date format
				foreach x of varlist firstrepaymentdate lastrepaymentdate ///
					agreementsigningdate effectivedatemostrecent {
						gen `x'2 = substr(`x', 1, strpos(`x', " ")-1)
						drop `x'
					}
				
				foreach x of varlist firstrepaymentdate2 lastrepaymentdate2 ///
					agreementsigningdate2 effectivedatemostrecent2 {
						gen `x'3 = date(`x', "MDY")
						format %td `x'3
					}
				
				drop firstrepaymentdate2 lastrepaymentdate2 agreementsigningdate2 effectivedatemostrecent2
				rename *23 *
			
			//drop all dates before 2000 and after 2014
				sort agreementsigningdate
				display date("20000101","YMD")  
				display date("20141231","YMD") 
				drop if agreementsigningdate<14610 //3,789 obs deleted
				drop if agreementsigningdate>20088 //1,375 obs deleted
		

		
		//drop all observations (loans/grants) that have been cancelled or terminated
			drop if creditstatus=="Fully Cancelled" | creditstatus=="Terminated" //52 obs deleted
			drop creditstatus	
		
		//drop if there is no value for the loan/grant amount
			drop if originalprincipalamount=="0" //30 obs deleted 
			
	
	//standardize variables for use in merged dataset

		//year
			gen year=yofd(agreementsigningdate)
			drop agreementsigningdate
			la var year "Year of agreement signing date"	
		
		//amount
			//merge deflators to data file
				merge m:m year using "$output/Inflation deflators USD 2014"
				drop _merge 
			
			//gen amount
				destring originalprincipalamount deflator, replace ignore(",")
				gen amount=originalprincipalamount/deflator
				la var amount "Value of grant/loan in USD 2014"	
				
		//cofinance
			gen cofinance=" "
			la var cofinance "Cofinancing institution(s)" 

		//country
		
		//countrycode
		
		//deflator
			la var deflator "Currency deflator (AidData methodology)"	
		
		//grace
			gen weekfirst = wofd(firstrepaymentdate)
			gen weeklast = wofd(lastrepaymentdate)
			gen weekstart = wofd(effectivedate)
			
			gen grace = (weekfirst-weekstart)/52
			replace grace=0 if grace<0 //0 real changes made
			drop firstrepaymentdate lastrepaymentdate effectivedate
			la var grace "Grace period, years"		
		
		//id
			rename creditnumber id 
			la var id "Unique identifier"
	

		//type
			gen type="Grant" if strpos(id, "H") | strpos(id,"D0")
			replace type="Loan" if type==""
			la var type "Loan or Grant"	
			
			
		//interest
			//"service charge rate" is comparable to an interest rate for concessional loans	
			rename servicechargerate interest
			replace interest=0 if interest==. & type=="Loan" //9 changes made		
			la var interest "Interest Rate"	
	
		//lender
			gen lender="IDA"
			la var lender "Lending institution(s)"			
		
		//maturity
			gen maturity = (weeklast-weekfirst)/52
			la var maturity "Maturity length, years"	
			
			drop weekfirst weekstart weeklast
				
		//originalamount
			rename originalprincipalamount originalamount
			la var originalamount "Value of grant/loan (USD) in agreement signing year"	

		//projectname
			egen projectname2 = concat(projectid projectname), punct(|)
			drop projectid projectname
			rename projectname2 projectname
			la var projectname "Project Name"	
		
		//region
		
		//source
			gen source="World Bank"
			label variable source "World Bank or China"
		
		/*type
			gen type="Grant" if strpos(id, "H") | strpos(id,"D0")
			replace type="Loan" if type==""
			la var type "Loan or Grant"
			*/
		
		//type_d
			gen type_d=""
			la var type_d "Loan or Grant, detailed"
		
		/*year
			gen year=yofd(agreementsigningdate)
			drop agreementsigningdate
			la var year "Year of agreement signing date"	*/
			
	
		//order and label all variables
			order id source country countrycode year type type_d amount deflator ///
				originalamount interest	maturity grace region lender cofinance projectname 
	
	//save file of cleaned IDA lending terms data
			save "$output/IDA clean", replace
		
		
		
		
/*==============================================================================
IBRD STATEMENT OF LOANS
==============================================================================*/		

	//import WB/IBRD dataset 
		import delimited "$input/IBRD_Statement_of_loans_-_Latest_Available_Snapshot", clear

		
	//remove variables that do not contribute to study objectives
		
		drop ïendofperiod borrower guarantorcountrycode guarantor currencyofcommitment ///
			cancelledamount undisbursedamount disbursedamount repaidtoibrd duetoibrd ///
			exchangeadjustment borrowersobligation sold3rdparty repaid3rdparty due3rdparty ///
			loansheld lastdisbursementdate
		
		//use "agreement signing date" as year unless missing, then use "board approval date"
			sort agreementsigningdate
			replace agreementsigningdate=boardapprovaldate if agreementsigningdate=="" //137 obs switched
		
		drop boardapprovaldate closeddatemostrecent
		
		
		
	//remove observations that fall outside the study objectives (time, space, status, etc)
		
		//drop all dates before 2000 and after 2014
				
			//convert dates from strings to date format
					foreach x of varlist firstrepaymentdate lastrepaymentdate ///
						agreementsigningdate effectivedatemostrecent {
							gen `x'2 = substr(`x', 1, strpos(`x', " ")-1)
							drop `x'
						}	
					
					foreach x of varlist firstrepaymentdate2 lastrepaymentdate2 ///
						agreementsigningdate2 effectivedatemostrecent2 {
							gen `x'3 = date(`x', "MDY")
							format %td `x'3
						}
					
					drop firstrepaymentdate2 lastrepaymentdate2 agreementsigningdate2 effectivedatemostrecent2
					rename *23 *
		
			//drop all dates before 2000 and after 2014
				sort agreementsigningdate
				display date("20000101","YMD") //14610 
				display date("20141231","YMD") //20088
				drop if agreementsigningdate<14610 //6,481 obs deleted
				drop if agreementsigningdate>20088 //575 obs deleted
		
		//drop all observations that are regional or multi-country loans
			drop if country=="World" //5 obs deleted
		
		//drop all observations that have been cancelled or terminated
			drop if loanstatus=="Fully Cancelled" | loanstatus=="Terminated" //56 obs deleted
			drop loanstatus	
		
		//drop if loantype is atypical
			drop if loantype=="CPL" | loantype=="GURB" //10 obs deleted
		
		//drop if there is no value for the loan/grant amount
			drop if originalprincipalamount=="0" //23 obs deleted 

		
		
	//standardize variables across datasets
		
		//year
			gen year=yofd(agreementsigningdate)
			la var year "Year of agreement signing date"			
		
		
		//amount
			//merge deflators to data file
				merge m:m year using "$output/Inflation deflators USD 2014"
				drop _merge 
			
			//gen amount
				destring originalprincipalamount deflator, replace ignore(",")
				gen amount=originalprincipalamount/deflator
				la var amount "Value of grant/loan in USD 2014"
			
		
		//cofinance
			gen cofinance=" "
			la var cofinance "Cofinancing institution(s)" 	
			
		//country
		
		//countrycode
		
		//deflator
			la var deflator "Currency deflator (AidData methodology)"	
		
		//grace
			gen weekfirst = wofd(firstrepaymentdate)
			gen weeklast = wofd(lastrepaymentdate)
			gen weekstart = wofd(effectivedate)
			
			gen grace = (weekfirst-weekstart)/52
				drop firstrepaymentdate lastrepaymentdate effectivedate
			replace grace=0 if grace<0 //7 real changes made//amount
			la var grace "Grace period, years"
		
		//id
			rename loannumber id
			la var id "Unique identifier"

		
		//maturity
			gen maturity = (weeklast-weekfirst)/52	
			la var maturity "Maturity length, years" 	
		
			drop weekfirst weekstart weeklast
		
		//interest		
			//merge LIBOR rates to agreement signing date
				merge m:1 agreementsigningdate using "$output/historical libor rates"		
					sort _merge
					drop if _merge==2
				
				sort agreementsigningdate
					replace libor=libor[_n-1] if missing(libor)
					drop _merge agreementsigningdate

				
			//merge WB LIBOR+ rates to dataset
				merge m:m country year using "$output/World Bank FLR"
					
				replace countrygrp = "A" if country=="Chad"
				replace countrygrp = "B" if country=="Iran, Islamic Republic of"
					
				drop if _merge==2
					
				sort countrygrp
				foreach x of var premium8 premium10 premium12 premium15 premium18 premium20 {
					replace `x'=`x'[_n-1] if missing(`x')
				}
				
				drop FSL08 FSL810 FSL1012 FSL1215 FSL1518 FSL1820 VSL08 VSL810 ///
					VSL1012 VSL1215 VSL1518 VSL1820 _merge
			
			//gen FSL interest rates, conditional on country group, maturity, and LIBOR rate
				gen interest2 = 		libor + premium20 if 					loantype=="FSL"
					replace interest2 = libor + premium18 if 	maturity<=18 & 	loantype=="FSL"
					replace interest2 = libor + premium15 if 	maturity<=15 & 	loantype=="FSL"
					replace interest2 = libor + premium12 if 	maturity<=12 & 	loantype=="FSL"			
					replace interest2 = libor + premium10 if 	maturity<=10 & 	loantype=="FSL"
					replace interest2 = libor + premium8 if 	maturity<=8 & 	loantype=="FSL"

				gen interest = interest2 if loantype=="FSL"
				replace interest = interestrate if loantype=="SCL"
					
				drop interestrate interest2 countrygrp SpecialStatus libor premium8 ///
					premium10 premium12 premium15 premium18 premium20

				la var interest "Interest Rate"

		//lender
			gen lender="IBRD"
			la var lender "Lending institution(s)"

		/*maturity
			gen maturity = (weeklast-weekfirst)/52	
			la var maturity "Maturity length, years" 	
		
			drop weekfirst weekstart weeklast 		*/
			
		//originalamount
			rename originalprincipalamount originalamount
			la var originalamount "Value of grant/loan (USD) in agreement signing year"		
			
		//project_name
			egen projectname2 = concat(projectid projectname), punct(|)
			drop projectid projectname
			rename projectname2 projectname
			la var projectname "Project Name"		

		//region
		
		//source
			gen source="World Bank"
			label variable source "World Bank or China"
		
		//type
			gen type="Loan"
			la var type "Loan or Grant"	
		
		//type_d
			rename loantype type_d
			la var type_d "Loan or Grant, detailed"
		
		/*year
			gen year=yofd(agreementsigningdate)
			la var year "Year of agreement signing date"	*/
			
		
		
		//order and label all variables
			order id source country countrycode year type type_d amount deflator ///
				originalamount interest	maturity grace region lender cofinance projectname 
	
	//save file of cleaned IBRD lending terms data
		save "$output/IBRD clean", replace	
			
		
		
		
		
		
		
/*==============================================================================
MERGE WORLD BANK AND AIDDATA DATASETS
==============================================================================*/		
clear
	
	//merge datafiles into one
		//merge IDA and IBRD into a single World Bank data file
			use "$output/IBRD clean", clear	
			append using "$output/IDA clean"
			
			//encode string variables
				encode type, gen(type2)
					drop type
					rename type2 type
					la var type "Loan or Grant"
			
				encode region, gen(region2)
					drop region
					rename region2 region
					la var region "Region"
				
				order id source country countrycode year type type_d amount deflator ///
					originalamount interest	maturity grace region lender cofinance projectname 
			
			//rename id for ease in appending to AidData
				rename id id2
						
			save "$output/World Bank clean" , replace

		//merge World Bank and AidData into a single data file	
			use "$output/AidData clean", clear
			destring deflator, replace
			append using "$output/World Bank clean", force
		
			save "$output/Full Dataset", replace
			
		
	//clean existing variables	
		//source
			label def source_lbl 0 "China" 1 "World Bank"
				encode source, gen(source2) label(source_lbl) 
				drop source
				rename source2 source
				label variable source "World Bank or China"		
		
		//amount
			format amount %15.0fc
		
		//cofinance
			label var cofinance "Cofinancing institution(s), China-only"
		
		//country
			tab country source
			
			replace country=	"Antigua and Barbuda" 				if country==	"Antigua & Barbuda"
			replace country=	"Bosnia and Herzegovina"			if country==	"Bosnia-Herzegovina"
			replace country=	"Cabo Verde"						if country==	"Cape Verde"	
			replace country=	"Central African Republic"			if country==	"Central African Rep."
			replace country=	"Congo, Democratic Republic of"		if country==	"Congo, Dem. Rep."
			replace country=	"Congo, Republic of"				if country==	"Congo, Rep."
			replace country=	"Cote d'Ivoire"						if country==	"Cote D'Ivoire"
			replace country=	"Egypt, Arab Republic of"			if country==	"Egypt"
			replace country=	"Iran, Islamic Republic of"			if country==	"Iran"
			replace country=	"Lao People's Democratic Republic"	if country==	"Laos"
			replace country=	"North Macedonia"					if country==	"Macedonia, FYR"
			replace country=	"Russian Federation"				if country==	"Russia"
			replace country=	"Trinidad and Tobago"				if country==	"Trinidad & Tobago"
			replace country=	"Venezuela, Republica Bolivariana de" if country==	"Venezuela"
			replace country=	"Vietnam"							if country==	"Viet Nam"
			replace country=	"Yemen, Republic of"				if country==	"Yemen"
			replace country=	"North Korea"						if country==	"Korea, Dem. Rep."
			replace country=	"Palestine"							if country==	"Palestinian Adm. Areas"
				//total: 239 changes made
		
			/*drop if country=="China" //169 obs deleted   */
		
		//countrycode
			replace countrycode=	"CD"	if countrycode==	"ZR" 	& source==1	//55 changes
			replace countrycode=	"RS" 	if countrycode==	"YF"	& source==1	//39 changes
			replace countrycode=	"TL"	if countrycode==	"TP"	& source==1	//13 changes
			replace countrycode=	"YE"	if countrycode==	"RY"	& source==1	//53 changes
		
		//deflator
			destring deflator, replace
			
		//grace
		
		//id
			tostring id, replace
			replace id=id2 if source==1
			drop id2
		
		//interest
			gen interest2=interest/100
			drop interest
			rename interest2 interest
			la var interest "Interest Rate"
		
		//lender_s
			rename lender lender_s
			la var lender_s "Lending institution(s), string"
		
		//maturity
			//adjust maturity length for 3 outliers
				replace maturity=10.0001 if id=="21096" ///
											| id=="30494" ///
											| id=="20080"
		
		//originalamount
		
		//projectname
		
		//region [didn't transfer for the World Bank observations]
			gen region2=.
			drop region
			rename region2 region
			la var region "Region"
			
			replace region = 2		if countrycode == "AS" | countrycode== "AU" | countrycode== "BN" ///
										| countrycode== "KH"| countrycode== "CN"| countrycode== "FJ" ///
										| countrycode== "PF"| countrycode== "GU"| countrycode== "HK" ///
										| countrycode== "ID"| countrycode== "JP"| countrycode== "KI" ///
										| countrycode== "KP"| countrycode== "KR"| countrycode== "LA" ///
										| countrycode== "MO"| countrycode== "MY"| countrycode== "MH" ///
										| countrycode== "FM"| countrycode== "MN"| countrycode== "MM" ///
										| countrycode== "NR"| countrycode== "NC"| countrycode== "NZ" ///
										| countrycode== "MP"| countrycode== "PW"| countrycode== "PG" ///
										| countrycode== "PH"| countrycode== "WS"| countrycode== "SG" ///
										| countrycode== "SB"| countrycode== "TW"| countrycode== "TH" ///
										| countrycode== "TL"| countrycode== "TO"| countrycode== "TV" ///
										| countrycode== "VU"| countrycode== "VN"| countrycode== "NU" ///
										| countrycode== "CK"

			replace region = 3 		if countrycode == "AL" | countrycode== "AD"| countrycode== "AM" ///
										| countrycode== "AT"| countrycode== "AZ"| countrycode== "BY" ///
										| countrycode== "BE"| countrycode== "BA"| countrycode== "BG" ///
										| countrycode== "CH"| countrycode== "HR"| countrycode== "CY" ///
										| countrycode== "CZ"| countrycode== "DK"| countrycode== "EE" ///
										| countrycode== "FO"| countrycode== "FI"| countrycode== "FR" ///
										| countrycode== "GE"| countrycode== "DE"| countrycode== "GI" ///
										| countrycode== "GR"| countrycode== "GL"| countrycode== "HU" ///
										| countrycode== "IS"| countrycode== "IE"| countrycode== "IM" ///
										| countrycode== "IT"| countrycode== "KZ"| countrycode== "XK" ///
										| countrycode== "KG"| countrycode== "LV"| countrycode== "LI" ///
										| countrycode== "LT"| countrycode== "LU"| countrycode== "MK" ///
										| countrycode== "MD"| countrycode== "MC"| countrycode== "ME" ///
										| countrycode== "NL"| countrycode== "NO"| countrycode== "PL" ///
										| countrycode== "PT"| countrycode== "RO"| countrycode== "RU" ///
										| countrycode== "SM"| countrycode== "RS"| countrycode== "SK" ///
										| countrycode== "SI"| countrycode== "ES"| countrycode== "SE" ///
										| countrycode== "CH"| countrycode== "TJ"| countrycode== "TR" ///
										| countrycode== "TM"| countrycode== "UA"| countrycode== "GB" ///
										| countrycode== "UZ"

			replace region = 4 		if countrycode == "AG"| countrycode=="AR"| countrycode== "AW" ///
										| countrycode== "BS"| countrycode== "BB"| countrycode== "BZ" ///
										| countrycode== "BO"| countrycode== "BR"| countrycode== "VG" ///
										| countrycode== "KY"| countrycode== "CL"| countrycode== "CO" ///
										| countrycode== "CR"| countrycode== "CU"| countrycode== "CW" ///
										| countrycode== "DM"| countrycode== "DO"| countrycode== "EC" ///
										| countrycode== "SV"| countrycode== "GD"| countrycode== "GT" ///
										| countrycode== "GY"| countrycode== "HT"| countrycode== "HN" ///
										| countrycode== "JM"| countrycode== "MX"| countrycode== "NI" ///
										| countrycode== "PA"| countrycode== "PY"| countrycode== "PE" ///
										| countrycode== "PR"| countrycode== "SX"| countrycode== "KN" ///
										| countrycode== "LC"| countrycode== "MF"| countrycode== "VC" ///
										| countrycode== "SR"| countrycode== "TT"| countrycode== "TC" ///
										| countrycode== "UY"| countrycode== "VE"| countrycode== "VI" 

			replace region = 5 		if countrycode == "DZ"| countrycode=="BH"| countrycode== "DJ" ///
										| countrycode== "EG"| countrycode== "IR"| countrycode== "IQ" ///
										| countrycode== "IL"| countrycode== "JO"| countrycode== "KW" ///
										| countrycode== "LB"| countrycode== "LY"| countrycode== "MT" ///
										| countrycode== "MA"| countrycode== "OM"| countrycode== "QA" ///
										| countrycode== "SA"| countrycode== "SY"| countrycode== "TN" ///
										| countrycode== "AE"| countrycode== "PS"| countrycode== "YE"

			replace region = 6 		if countrycode == "AF"| countrycode=="BD"|countrycode== "BT" ///
										| countrycode== "IN"| countrycode== "MV"| countrycode== "NP" ///
										| countrycode== "PK"| countrycode== "LK"

			replace region = 1 		if countrycode == "AO" | countrycode== "BJ"| countrycode== "BW" ///
										| countrycode== "BF"| countrycode== "BI"| countrycode== "CV" ///
										| countrycode== "CM"| countrycode== "CF"| countrycode== "TD" ///
										| countrycode== "KM"| countrycode== "CD"| countrycode== "CG" ///
										| countrycode== "CI"| countrycode== "GQ"| countrycode== "ER" ///
										| countrycode== "ET"| countrycode== "GA"| countrycode== "GM" ///
										| countrycode== "GH"| countrycode== "GN"| countrycode== "GW" ///
										| countrycode== "KE"| countrycode== "LS"| countrycode== "LR" ///
										| countrycode== "MG"| countrycode== "MW"| countrycode== "ML" ///
										| countrycode== "MR"| countrycode== "MU"| countrycode== "MZ" ///
										| countrycode== "NA"| countrycode== "NE"| countrycode== "NG" ///
										| countrycode== "RW"| countrycode== "ST"| countrycode== "SN" ///
										| countrycode== "SC"| countrycode== "SL"| countrycode== "SO" ///
										| countrycode== "ZA"| countrycode== "SS"| countrycode== "SD" ///
										| countrycode== "SZ"| countrycode== "TZ"| countrycode== "TG" ///
										| countrycode== "UG"| countrycode== "ZM"| countrycode== "ZW"
			//encode regoin
				label define region_lbl 	1 	"Sub-Saharan Africa" ///
											2 	"East Asia and Pacific" ///
											3	"Europe and Central Asia" ///
											4 	"Latin America and the Caribbean" ///
											5 	"Middle East and North Africa" ///
											6 	"South Asia"
				label value region region_lbl

				
		/*source
			label def source 0 "China" 1 "World Bank"
				encode source, gen(source2) label(source) 
				drop source
				rename source2 source
				label variable source "World Bank or China"			*/
		
		//type
			label def type_lbl 1 "Grant" 2 "Loan"
			la values type type_lbl
		
		//type_d
			gen type2=.
			
			replace type2=1		if type==1
			replace type2=2		if type==2 & lender_s=="IDA"
			replace type2=3		if type_d=="SCL"
			replace type2=4		if type_d=="FSL"
			replace type2=5		if type_d=="Loan (excluding debt rescheduling)"
			replace type2=6		if type_d=="Export credits"
			
			label define typed_lbl 	1 	"Grant" ///
									2 	"Loan: IDA" ///
									3 	"Loan: IBRD (single currency)" ///
									4 	"Loan: IBRD (fixed or variable spread)" ///
									5 	"Loan: China" ///
									6 	"Loan: China (export credits)"
			
			label val type2 typed_lbl
			
			drop type_d
			
			rename type2 type_d
			
			la var type_d "Loan or Grant, detailed"
		
		//year
		
		
		//order
			order id source country countrycode year type type_d amount deflator ///
				originalamount interest maturity grace region lender cofinance projectname
	
	
	
	//create new variables			
		
		//categorical variables (lender type, income group, lending group (IDA/Blend/IBRD)
			
			//lender
				
				gen lender=.
				
				//define different lender groupings
					replace lender=1 if strpos(lender_s, 	"Government Agency")
					replace lender=1 if strpos(lender_s,	"Chinese Communist Party")
					replace lender=1 if strpos(lender_s,	"China Central Bank")
					
					replace lender=2 if strpos(lender_s, 	"CDB")
					replace lender=2 if strpos(lender_s, 	"Export-Import Bank of China") 
						
					replace lender=3 if strpos(lender_s, 	"State-Owned Company")
						
					replace lender=4 if strpos(lender_s, 	"Agricultural Bank of China")
					replace lender=4 if strpos(lender_s, 	"BOC")
					replace lender=4 if strpos(lender_s, 	"CCB")
					replace lender=4 if strpos(lender_s, 	"China Communications Bank")
					replace lender=4 if strpos(lender_s, 	"ICBC")
						
					replace lender=5 if strpos(lender_s, 	"Unspecified Chinese Government Institution")
					replace lender=5 if strpos(lender_s,	"unspecified Chinese Government Institution")
						
					replace lender=6 if strpos(lender_s, 	";")
					replace lender=6 if						cofinance !=""

					replace lender=7 if 					source==1 //World Bank
					replace lender=1 if strpos(lender_s,	"China Central Bank") //outlier, really People's Bank of China and gov't agency
					
				//label define for lender_type
					label define lender_lbl 	1 	"Government Agency" ///
												2 	"Policy Bank" ///
												3 	"State-Owned Enterprise" ///
												4 	"State-Owned Commercial Bank" ///
												5	"Unspecified Chinese Institution" ///
												6 	"Co-financed" ///
												7 	"World Bank"
						
						label values lender lender_lbl
						
						la var lender "Lending institution(s), categorical"
			
			//lender_d
				gen lender_d=.
				
				//define detailed lender groupings
					replace lender_d=1 	if lender==				1 //Government Agency
					replace lender_d=2 	if strpos(lender_s, 	"Ministry of Commerce")
					replace lender_d=3 	if strpos(lender_s, 	"Chinese Embassy/Consulate")
					
					replace lender_d=4 	if strpos(lender_s, 	"CDB")
					replace lender_d=5 	if strpos(lender_s, 	"Export-Import Bank of China") 
		
					replace lender_d=6 	if lender==				3 //State-Owned Enterprise
					
					replace lender_d=7 	if lender==				4 // State-Owned Commercial Banks
					replace lender_d=8 	if strpos(lender_s, 	"BOC")
					replace lender_d=9 	if strpos(lender_s, 	"ICBC")
						
					replace lender_d=10 if lender== 			5 //Unspecified Chinese Government Institution
						
					replace lender_d=11 if lender==				6 // Co-financed
					replace lender_d=.	if strpos(cofinance,	"BNP Paribas S.A., Private Sector")	
					replace lender_d=.	if strpos(cofinance,	"Mitsui Banking Corporation")

					replace lender_d=12	if strpos(cofinance, 	"Multilateral")
					replace lender_d=12 if strpos(cofinance, 	"Development Bank of Southern Africa")
						
					replace lender_d=13 if strpos(cofinance, 	"Government Agency")
					replace lender_d=13	if strpos(cofinance,	"BNDES")
					replace lender_d=13 if strpos(cofinance, 	"Camtel")	
					replace lender_d=13 if strpos(cofinance, 	"Ceylon")
					replace lender_d=13 if strpos(cofinance, 	"Libyan")
					replace lender_d=13 if strpos(cofinance, 	"Oi")
					replace lender_d=13 if strpos(cofinance, 	"Standard Bank of South Africa")
					replace lender_d=13 if strpos(cofinance, 	"Taitokerau")
					replace lender_d=13 if strpos(cofinance, 	"Uzbekistan's")					
					replace lender_d=13 if strpos(cofinance, 	"Vale of Brazil")	
					replace lender_d=13 if strpos(cofinance, 	"Zimbabwe Power Company")
											
					replace lender_d=14	if strpos(lender_s, 	"IDA")
					replace lender_d=15	if strpos(lender_s, 	"IBRD")	
						
					replace lender_d=13	if strpos(lender_s,		"BNP Paribas")
					replace lender_d=.	if strpos(lender_s,		"Sumitomo Mitsui")		
			
			//label define for lender_d
					label define lenderd_lbl 	1 	"Gov Agency: Other" ///
												2 	"Gov Agency: Ministry of Commerce" ///
												3 	"Gov Agency: Chinese Embassy/Consulate" ///
												4 	"Policy Bank: China Development Bank" ///
												5 	"Policy Bank: China Exim Bank" ///
												6 	"State-Owned Enterprise" ///
												7 	"State-Owned Commercial Bank: Other" ///
												8 	"SOCB: Bank of China (BOC)" ///
												9 	"SOCB: Industrial and Commercial Bank of China (ICBC)" ///
												10 	"Unspecified Chinese Institution" ///
												11 	"Co-financed: China only" ///
												12 	"Co-financed: Multilateral Organization" ///
												13 	"Co-financed: Recipient Country Organization" ///
												14 	"World Bank: IDA" ///
												15 	"World Bank: IBRD"
					
					label values lender_d lenderd_lbl
					la var lender_d "Lending institution(s), detailed categorical"
			
		
		
			//income			
				
				//import historical lending categories dataset
					save "$output/Full Dataset", replace
					
					import excel "$input/Historical Income Categories.xls", ///
						sheet("Country Analytical History") firstrow clear
			
					drop A R-IE
					rename Dataforcalendaryear country
					la var country "Country"
			
					rename D-Q yr=
					rename yr* yr20(##), renumber
					rename C yr2000
			
					sort country
					drop in 1/1
			
					reshape long yr, i(country) j(year)
					rename yr income	
			
					save "$output/Historical income categories", replace
					
				//merge with full dataset
					use "$output/Full Dataset", clear
					merge m:m country year using "$output/Historical income categories"
				
					drop if _merge==2
					drop _merge
						
					la define income_lbl 1 "L" 2 "LM" 3 "UM" 4 "H"
					encode income, gen(income2) label(income)
					drop income
					rename income2 income
					la var income "Income categories"
					
			//lendgrp
			
				//import historical lending categories dataset
					save "$output/Full Dataset", replace
					
					import excel "$input/Historical Lending Categories.xls", sheet("Lending Groups") firstrow clear
			
					rename Economy country
					la var country "Country"
					drop R
					
					rename C-Q yr=
					rename yr* yr20(##), renumber
					rename (B Current) (yr2000 yr2019)
					
					sort country
					drop in 1/11	
					
					reshape long yr, i(country) j(lendgrp)
					rename (lendgrp yr) (year lendgrp)
					
					save "$output/Historical lending categories", replace
					
				//merge with full dataset
					use "$output/Full Dataset", clear
					merge m:m country year using "$output/Historical lending categories"
					
					drop if _merge==2
					replace lendgrp="NB" if 	lendgrp=="preWB" ///
												| country=="Cook Islands" ///
												| country=="Niue" ///
												| country=="North Korea" ///
												| country=="Vanuatu"
					
					drop _merge
					
					la define lendgrp_lbl 0 "NB" 1 "IDA" 2 "Blend" 3 "IBRD"
					encode lendgrp, gen(lendgrp2) label(lendgrp_lbl)
					drop lendgrp
					rename lendgrp2 lendgrp					
					la var lendgrp "World Bank lending categories"
					
		//Analytical variables
			//info
				//Information on Variables of Interest: Full, Some, None
		
					//recode grant observations with lending information as loans
						replace type=2 if id=="35662" ///
										| id=="34702" ///
										| id=="38626"
						replace type_d=5 if id=="35662" ///
										| id=="34702" ///
										| id=="38626"				

					//create new variable measuring prevelance of the variables of interest
		
						gen info=.
						replace info=1 if missing(interest) | missing(maturity) | missing(grace)
						replace info=0 if missing(interest) & missing(maturity) & missing(grace)
						replace info=2 if interest!=. & maturity!=. & grace!=.
						replace info=3 if type==1
					
						label define info_lbl 0 "No information" 1 "Some information" 2 "Full information" 3 "Grant"
						label values info info_lbl
						la var info "Data completeness of lending terms"
		
			//grantelement
				//grant element of a loan, unbounded
					gen grantelement = .
					replace grantelement = (1 - ((interest/2)/((1.05^0.5)-1)))*(1 - (((1/((1+((1.05^0.5)-1))^(2*grace)))-(1/((1+((1.05^0.5)-1))^(2*maturity))))/(((1.05^0.5)-1)*((2*maturity)-(2*grace)))))
					replace grantelement=. if info!=2
						
					la var grantelement "Grant element, unbounded"
					
			//grantelement_b
				//grant element of a loan, bounded 0-100	
					gen grantelement_b = grantelement
					replace grantelement_b = 0 if grantelement_b<=0
					replace grantelement_b= 1.00 if grantelement_b>=100
					replace grantelement_b=. if grantelement==.
				
					la var grantelement_b "Grant element, bounded 0-100"
					
			
			//subset
				//determine which countries to include in the subsample.
				//Cutoff: Y if 25% of loans in a given country have full information
				
				//create variable for # of loans per country
					bysort country: egen numloan=count(type) if type==2 & source==0
					
					gsort country source -type
					replace numloan=numloan[_n-1] if country==country[_n-1]
					
					replace numloan=0 if source==0 & type==1 & numloan==.
					gsort country source -type
					replace numloan=numloan[_n-1] if country==country[_n-1] & numloan==.
					
					replace numloan=0 if type==1 & source==1 & numloan==.
					replace numloan=0 if type==2 & source==1 & numloan==.
									
				//create variable for # of loans with full info per country
					bysort country: egen numloanfull=count(type) if type==2 & info==2 & source==0							
					gsort country source -type -info
					replace numloanfull=numloanfull[_n-1] if country==country[_n-1]
					
					replace numloanfull=0 if numloanfull==.
					/*
					replace numloanfull=0 if type==2 & source==0 & numloanfull==. & info==1|info==0
					replace numloanfull=numloanfull[_n-1] if country==country[_n-1] & numloanfull==.

				
					replace numloanfull=0 if numloan==0
					
					replace numloanfull=0 if type==2 & source==0 & numloanfull==. & info==1|info==0
					
					replace numloanfull=numloanfull[_n-1] if country==country[_n-1] & numloanfull==. */
				
				//create cutoff variable
					bysort country: gen cutoff=numloanfull/numloan
					replace cutoff=0 if cutoff==.
					la var cutoff "Percent of Chinese loans with full information on lending terms"
					
				//create subset variable
					gen subset=0
					replace subset=1 if cutoff>=.25
					
					replace subset=0 if country=="Cook Islands"
					replace subset=0 if country=="Vanuatu"
							//no World Bank lending to these countries
							
					la var subset "Included in country subsample"
					label define subset_lbl 0 "No" 1 "Yes"
					label values subset subset_lbl

				drop numloan numloanfull
				
//Final Dataset
	order id source country countrycode year type type_d amount deflator ///
		originalamount interest	maturity grace grantelement grantelement_b ///
		subset info cutoff region income lendgrp lender lender_d lender_s ///
		cofinance projectname 
		
	save "$output/Full Dataset", replace	
		
		
		
		
		
		
		
		
		
		
		
		
		